package org.rexxla.bsf.engines.rexx;   // belongs to that fine package ...

import com.ibm.bsf.*;   // BSF support
import java.io.*;       // exception handling


/** Java class to allow Rexx to invoke <code>BSF4Rexx</code> via JNI, after the JVM was created.
 *  <p>
 *  <code>&quot;BSF4Rexx.BsfLoadJava()&quot;</code> will create a JVM, load this class and
 *  then invoke the static method {@link #createInterface4Rexx()}. This method creates an instance
 *  of {@link BSFManager} and uses it to load an instance of the Rexx engine, which allows
 *  to initialize the <code>&quot;BSF4Rexx&quot;</code> link library.
 *
 *  <p>
 *  To make sure that
 *  upon return from the static method {@link #createInterface4Rexx()} the reference
 *  to the Rexx engine object received via {@link RexxEngine#getRexxInterface()
 *  RexxEngine.getRexxInterface()}, a
 *  global reference is created via JNI while executing the method
 *  {@link RexxAndJava#jniInitialize4Rexx() RexxAndJava.jniInitialize4Rexx()}, which
 *  calls into the BSF4Rexx-DLL.
 *
 *  @author   Rony G. Flatscher, 2005-06-02
  * @version 2.5.0, 2005-06-02
  * @since 2003-01-21 by Rony G. Flatscher
 */
class Java4Rexx {

  /**  BSF-manager to be used to get (instantiate) the Rexx engine. */
  static private BSFManager bsfMgr=null;

  /** The Rexx engine loaded via {@link #bsfMgr}. */
  static private BSFEngine  rxEngine=null;

  /** This method allows Rexx to load Java, then initialize
   *  the BSF4Rexx infrastructure from the Java side, and
   *  thereafter use all of the infrastructure from Rexx.
   *
   * <p> Hint: JNI is able to get to private/protected members of a class! This way this method
   * can <em>only</em> be invoked by JNI.
   *
    */
  private static void createInterface4Rexx() throws IOException {

    try {
        bsfMgr  = new BSFManager ();   // create and initialize a BSFManager
        // this will load BSF4Rexx.dll from the Java side and initialize
        rxEngine = bsfMgr.loadScriptingEngine("rexx");   // now the Rexx Engine and its supporting class is available
    }
    catch (BSFException e)
    {
      e.printStackTrace();
    }

        // now call into the DLL ("BSF4Rexx.dll") in order to initialize
    ((RexxEngine) rxEngine).getRexxInterface().jniInitialize4Rexx();
  }
}

